@@ -51,6 +51,7 @@ def init_args() -> Namespace:
     parser.add_argument("-f", "--format", choices=list(set(AVAILABLE_FORMATS.values())))
     parser.add_argument("--prometheus", default=False, action="store_true")
     parser.add_argument("--prometheus-filters", default={}, type=json.loads)
+    parser.add_argument("--blackbox-exporter", default=False, action="store_true")
     parser.add_argument("--context", nargs="?")
     parser.add_argument("--cloudwatch", default=False, action="store_true")
     parser.add_argument("--aws-profile", default=os.getenv("AWS_PROFILE", None))
@@ -147,6 +148,11 @@ def main():
         k = Kubernetes(context=args.context, filters=args.prometheus_filters)
         k.get_prometheus_rules()
         alert_count += len(k.rules)
+    if args.blackbox_exporter:
+        if "k" not in locals():
+            k = Kubernetes(context=args.context)
+        k.get_blackbox_exporter_targets()
+        alert_count += len(k.targets)
     if alert_count == 0:
         logging.warning("No alert found.")
         return 1
@@ -174,6 +180,7 @@ def main():
             "cloudwatch": c.alarms if args.cloudwatch else [],
             "pingdom": p.checks if args.pingdom else [],
             "prometheus": k.rules if args.prometheus else [],
+            "Blackbox Exporter": k.targets if args.blackbox_exporter else [],
         },
         output_file=args.output_file,
     )
